MINUTE_IN_SECONDS: int = 60

HOUR_IN_SECONDS: int = MINUTE_IN_SECONDS * 60

DAY_IN_SECONDS: int = HOUR_IN_SECONDS * 24

WEEK_IN_SECONDS: int = DAY_IN_SECONDS * 7

MONTH_IN_SECONDS: int = WEEK_IN_SECONDS * 4

YEAR_IN_SECONDS: int = WEEK_IN_SECONDS * 52
